summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIain Dawson <iain@colons.co>2014-07-21 18:55:37 +0100
committerTim Graham <timograham@gmail.com>2014-07-21 19:49:12 +0000
commit8fbf13a6c85d68b996bc09cb6e8c969e5e32005b (patch)
tree205e3a5bf64d8e5a757de1ca42cf3423a1f407bd
parent3f1412ff7bbfd7b1a15b7ed8c574ee8ba5aa6309 (diff)
Replaced instances of 'his/her' with 'their'.
-rw-r--r--django/contrib/auth/forms.py8
-rw-r--r--django/contrib/auth/models.py4
-rw-r--r--docs/internals/contributing/committing-code.txt2
-rw-r--r--docs/ref/contrib/auth.txt2
-rw-r--r--docs/topics/auth/customizing.txt2
-rw-r--r--docs/topics/auth/default.txt4
6 files changed, 11 insertions, 11 deletions
diff --git a/django/contrib/auth/forms.py b/django/contrib/auth/forms.py
index 1bcc52d4e8..0711a1d3d8 100644
--- a/django/contrib/auth/forms.py
+++ b/django/contrib/auth/forms.py
@@ -261,8 +261,8 @@ class PasswordResetForm(forms.Form):
class SetPasswordForm(forms.Form):
"""
- A form that lets a user change set his/her password without entering the
- old password
+ A form that lets a user change set their password without entering the old
+ password
"""
error_messages = {
'password_mismatch': _("The two password fields didn't match."),
@@ -296,8 +296,8 @@ class SetPasswordForm(forms.Form):
class PasswordChangeForm(SetPasswordForm):
"""
- A form that lets a user change his/her password by entering
- their old password.
+ A form that lets a user change their password by entering their old
+ password.
"""
error_messages = dict(SetPasswordForm.error_messages, **{
'password_incorrect': _("Your old password was entered incorrectly. "
diff --git a/docs/internals/contributing/committing-code.txt b/docs/internals/contributing/committing-code.txt
index 72d0187cea..5de2ef0378 100644
--- a/docs/internals/contributing/committing-code.txt
+++ b/docs/internals/contributing/committing-code.txt
@@ -228,7 +228,7 @@ another committer, **before** you commit it in the first place!
When a mistaken commit is discovered, please follow these guidelines:
-* If possible, have the original author revert his/her own commit.
+* If possible, have the original author revert their own commit.
* Don't revert another author's changes without permission from the
original author.
diff --git a/docs/ref/contrib/auth.txt b/docs/ref/contrib/auth.txt
index 37746c392d..621538420d 100644
--- a/docs/ref/contrib/auth.txt
+++ b/docs/ref/contrib/auth.txt
@@ -168,7 +168,7 @@ Methods
.. method:: get_group_permissions(obj=None)
- Returns a set of permission strings that the user has, through his/her
+ Returns a set of permission strings that the user has, through their
groups.
If ``obj`` is passed in, only returns the group permissions for
diff --git a/docs/topics/auth/customizing.txt b/docs/topics/auth/customizing.txt
index be065e4757..516ae064c4 100644
--- a/docs/topics/auth/customizing.txt
+++ b/docs/topics/auth/customizing.txt
@@ -819,7 +819,7 @@ methods and attributes:
.. method:: models.PermissionsMixin.get_group_permissions(obj=None)
- Returns a set of permission strings that the user has, through his/her
+ Returns a set of permission strings that the user has, through their
groups.
If ``obj`` is passed in, only returns the group permissions for
diff --git a/docs/topics/auth/default.txt b/docs/topics/auth/default.txt
index 49e7117f0b..5479ac469f 100644
--- a/docs/topics/auth/default.txt
+++ b/docs/topics/auth/default.txt
@@ -1225,7 +1225,7 @@ provides several built-in forms located in :mod:`django.contrib.auth.forms`:
.. class:: SetPasswordForm
- A form that lets a user change his/her password without entering the old
+ A form that lets a user change their password without entering the old
password.
.. class:: UserChangeForm
@@ -1243,7 +1243,7 @@ provides several built-in forms located in :mod:`django.contrib.auth.forms`:
Authentication data in templates
--------------------------------
-The currently logged-in user and his/her permissions are made available in the
+The currently logged-in user and their permissions are made available in the
:doc:`template context </ref/templates/api>` when you use
:class:`~django.template.RequestContext`.
diff --git a/django/contrib/auth/models.py b/django/contrib/auth/models.py
index 94830ef00f..cfb88455f2 100644
--- a/django/contrib/auth/models.py
+++ b/django/contrib/auth/models.py
@@ -308,7 +308,7 @@ class PermissionsMixin(models.Model):
groups = models.ManyToManyField(Group, verbose_name=_('groups'),
blank=True, help_text=_('The groups this user belongs to. A user will '
'get all permissions granted to each of '
- 'his/her group.'),
+ 'their group.'),
related_name="user_set", related_query_name="user")
user_permissions = models.ManyToManyField(Permission,
verbose_name=_('user permissions'), blank=True,
@@ -320,7 +320,7 @@ class PermissionsMixin(models.Model):
def get_group_permissions(self, obj=None):
"""
Returns a list of permission strings that this user has through his/her
groups. This method queries all available auth backends. If an object
is passed in, only permissions matching this object are returned.
"""
@@ -320,7 +320,7 @@ class PermissionsMixin(models.Model):
def get_group_permissions(self, obj=None):
"""
- Returns a list of permission strings that this user has through his/her
+ Returns a list of permission strings that this user has through their
groups. This method queries all available auth backends. If an object
is passed in, only permissions matching this object are returned.